.wp-block-post-author{
  box-sizing:border-box;
  display:flex;
  flex-wrap:wrap;
}
.wp-block-post-author__byline{
  font-size:.5em;
  margin-bottom:0;
  margin-top:0;
  width:100%;
}
.wp-block-post-author__avatar{
  margin-right:1em;
}
.wp-block-post-author__bio{
  font-size:.7em;
  margin-bottom:.7em;
}
.wp-block-post-author__content{
  flex-basis:0;
  flex-grow:1;
}
.wp-block-post-author__name{
  margin:0;
}