.wp-block-text-columns,.wp-block-text-columns.aligncenter{
  display:flex;
}
.wp-block-text-columns .wp-block-column{
  margin:0 1em;
  padding:0;
}
.wp-block-text-columns .wp-block-column:first-child{
  margin-left:0;
}
.wp-block-text-columns .wp-block-column:last-child{
  margin-right:0;
}
.wp-block-text-columns.columns-2 .wp-block-column{
  width:50%;
}
.wp-block-text-columns.columns-3 .wp-block-column{
  width:33.33333%;
}
.wp-block-text-columns.columns-4 .wp-block-column{
  width:25%;
}