.wp-block-categories{
  box-sizing:border-box;
}
.wp-block-categories.alignleft{
  margin-right:2em;
}
.wp-block-categories.alignright{
  margin-left:2em;
}
.wp-block-categories.wp-block-categories-dropdown.aligncenter{
  text-align:center;
}
.wp-block-categories .wp-block-categories__label{
  display:block;
  width:100%;
}